gnucash-on-windows master: Multiple changes pushed

John Ralls jralls at code.gnucash.org
Sun Oct 5 17:55:53 EDT 2014


Updated	 via  https://github.com/Gnucash/gnucash-on-windows/commit/418b95a4 (commit)
	 via  https://github.com/Gnucash/gnucash-on-windows/commit/31e98201 (commit)
	from  https://github.com/Gnucash/gnucash-on-windows/commit/22cb89a3 (commit)



commit 418b95a4de770438682535eedfee8c660ef611a8
Author: John Ralls <jralls at ceridwen.us>
Date:   Sun Oct 5 15:55:40 2014 -0700

    Don't build boost except when building "master".

diff --git a/install-impl.sh b/install-impl.sh
index 56cd39b..29b50e6 100644
--- a/install-impl.sh
+++ b/install-impl.sh
@@ -1235,6 +1235,11 @@ function inst_gnucash() {
     _REPOS_UDIR=`unix_path $REPOS_DIR`
     mkdir -p $_BUILD_UDIR
     add_to_env $_INSTALL_UDIR/bin PATH
+    if [ "$GNUCASH_SCM_REV" = "master" ]; then
+        _MASTER_OPTIONS="--with-boost=${BOOST_ROOT}"
+    else
+        _MASTER_OPTIONS=""
+    fi
 
     AQBANKING_OPTIONS="--enable-aqbanking"
     AQBANKING_UPATH="${_OPENSSL_UDIR}/bin:${_GWENHYWFAR_UDIR}/bin:${_AQBANKING_UDIR}/bin"
@@ -1256,7 +1261,7 @@ function inst_gnucash() {
             ${AQBANKING_OPTIONS} \
             --enable-binreloc \
             --enable-locale-specific-tax \
-            --with-boost=${BOOST_ROOT} \
+            ${_MASTER_OPTIONS} \
             CPPFLAGS="${REGEX_CPPFLAGS} ${GNOME_CPPFLAGS} ${GUILE_CPPFLAGS} ${LIBDBI_CPPFLAGS} ${KTOBLZCHECK_CPPFLAGS} ${HH_CPPFLAGS} ${LIBSOUP_CPPFLAGS} -D_WIN32 ${EXTRA_CFLAGS}" \
             LDFLAGS="${REGEX_LDFLAGS} ${GNOME_LDFLAGS} ${GUILE_LDFLAGS} ${LIBDBI_LDFLAGS} ${KTOBLZCHECK_LDFLAGS} ${HH_LDFLAGS} -L${_SQLITE3_UDIR}/lib -L${_ENCHANT_UDIR}/lib -L${_LIBXSLT_UDIR}/lib -L${_MINGW_UDIR}/lib" \
             PKG_CONFIG_PATH="${PKG_CONFIG_PATH}"
diff --git a/defaults.sh b/defaults.sh
index 85008b7..e62df89 100644
--- a/defaults.sh
+++ b/defaults.sh
@@ -228,8 +228,6 @@ set_default LIBXSLT_DIR $GLOBAL_DIR\\libxslt
 
 set_default EXPAT_URL               "$GNOME_WIN32_DEPS_URL/expat_2.0.1-1_win32.zip"
 set_default EXPAT_DEV_URL           "$GNOME_WIN32_DEPS_URL/expat-dev_2.0.1-1_win32.zip"
-set_default FONTCONFIG_URL          "$GNOME_WIN32_DEPS_URL/fontconfig_2.8.0-2_win32.zip"
-set_default FONTCONFIG_DEV_URL      "$GNOME_WIN32_DEPS_URL/fontconfig-dev_2.8.0-2_win32.zip"
 set_default FREETYPE_URL            "$GNOME_WIN32_DEPS_URL/freetype_2.4.4-1_win32.zip"
 set_default FREETYPE_DEV_URL        "$GNOME_WIN32_DEPS_URL/freetype-dev_2.4.4-1_win32.zip"
 set_default GAIL_URL                "$GNOME_WIN32_URL/gail/1.22/gail-1.22.0.zip"
@@ -261,6 +259,8 @@ set_default CAIRO_VERSION="1.12.2"
 set_default CAIRO_URL               "$GC_DEPS_URL/cairo-1.12.16-minGW.tgz"
 set_default GTK_VERSION="2.24.24"
 set_default GTK_URL                 "$GC_DEPS_URL/gtk+-2.24.24-minGW.tgz"
+set_default ZLIB_URL                "$GNOME_WIN32_DEPS_URL/zlib_1.2.5-2_win32.zip"
+set_default ZLIB_DEV_URL            "$GNOME_WIN32_DEPS_URL/zlib-dev_1.2.5-2_win32.zip"
 
 set_default GNOME_DIR $GLOBAL_DIR\\gnome
 
diff --git a/dist-impl.sh b/dist-impl.sh
index b6e1a9f..a2ff7fe 100755
--- a/dist-impl.sh
+++ b/dist-impl.sh
@@ -87,7 +87,6 @@ function dist_gnome() {
     setup Gnome platform
     wget_unpacked $CAIRO_URL $DOWNLOAD_DIR $DIST_DIR
     wget_unpacked $EXPAT_URL $DOWNLOAD_DIR $DIST_DIR
-    wget_unpacked $FONTCONFIG_URL $DOWNLOAD_DIR $DIST_DIR
     wget_unpacked $FREETYPE_URL $DOWNLOAD_DIR $DIST_DIR
     wget_unpacked $GAIL_URL $DOWNLOAD_DIR $DIST_DIR
     wget_unpacked $GETTEXT_RUNTIME_URL $DOWNLOAD_DIR $DIST_DIR
diff --git a/install-impl.sh b/install-impl.sh
index e5de149..56cd39b 100644
--- a/install-impl.sh
+++ b/install-impl.sh
@@ -361,8 +361,6 @@ function inst_gnome() {
         wget_unpacked $CAIRO_URL $DOWNLOAD_DIR $GNOME_DIR
         wget_unpacked $EXPAT_URL $DOWNLOAD_DIR $GNOME_DIR
         wget_unpacked $EXPAT_DEV_URL $DOWNLOAD_DIR $GNOME_DIR
-        wget_unpacked $FONTCONFIG_URL $DOWNLOAD_DIR $GNOME_DIR
-        wget_unpacked $FONTCONFIG_DEV_URL $DOWNLOAD_DIR $GNOME_DIR
         wget_unpacked $FREETYPE_URL $DOWNLOAD_DIR $GNOME_DIR
         wget_unpacked $FREETYPE_DEV_URL $DOWNLOAD_DIR $GNOME_DIR
         wget_unpacked $GAIL_URL $DOWNLOAD_DIR $GNOME_DIR
@@ -382,7 +380,8 @@ function inst_gnome() {
         wget_unpacked $LIBTIFF_DEV_URL $DOWNLOAD_DIR $GNOME_DIR
         wget_unpacked $PKG_CONFIG_URL $DOWNLOAD_DIR $GNOME_DIR
         wget_unpacked $PKG_CONFIG_DEV_URL $DOWNLOAD_DIR $GNOME_DIR
-
+        wget_unpacked $ZLIB_URL $DOWNLOAD_DIR $GNOME_DIR
+        wget_unpacked $ZLIB_DEV_URL $DOWNLOAD_DIR $GNOME_DIR
         echo 'gtk-theme-name = "Nimbus"' > ${_GNOME_UDIR}/etc/gtk-2.0/gtkrc
 
         wget_unpacked $GTK_THEME_URL $DOWNLOAD_DIR $TMP_DIR



Summary of changes:
 defaults.sh     |  4 ++--
 dist-impl.sh    |  1 -
 install-impl.sh | 12 ++++++++----
 install.sh      |  6 ++++--
 4 files changed, 14 insertions(+), 9 deletions(-)



More information about the gnucash-changes mailing list
diff --git a/install.sh b/install.sh
index ec5065e..adab052 100644
--- a/install.sh
+++ b/install.sh
@@ -99,8 +99,10 @@ add_step inst_libdbi
 add_step inst_libsoup
 add_step inst_enchant
 add_step inst_webkit
-#boost now needed for C++
-add_step inst_boost
+#boost now needed for C++ on master only
+if [ "$GNUCASH_SCM_REV" = "master" ]; then
+  add_step inst_boost
+fi
 
 ##
 if [ "$WITH_CUTECASH" = "yes" ]; then

commit 31e9820132264540ec481b737ffd5a8919a359ae
Author: John Ralls <jralls at ceridwen.us>
Date:   Sun Oct 5 15:54:51 2014 -0700

    Some fixups for building with the new gtk stack.
